provider "google" {
  project     = "<project-id>"
  region      = "us-west1"
  zone        = "us-west1-a"
}

# VPC network and subnet for our server instance
resource "google_compute_network" "simple_server_network" {
  name                    = "simple-server-network"
  auto_create_subnetworks = false
  mtu                     = 1460
}

resource "google_compute_subnetwork" "simple_server_subnet" {
  name          = "simple-server-subnet"
  ip_cidr_range = "10.0.1.0/24"
  network       = google_compute_network.simple_server_network.id
}

# Firewall rule to allow traffic on port 8080
resource "google_compute_firewall" "simple_server_firewall" {
  name    = "allow-8080-traffic"
  network = google_compute_network.simple_server_network.id

  allow {
    protocol = "tcp"
    ports    = ["8080"]
  }
  direction     = "INGRESS"
  priority      = 1000
  source_ranges = ["0.0.0.0/0"]
}

# Firewall rule to allow ssh access (traffic on port 22)
resource "google_compute_firewall" "ssh_firewall" {
  name    = "allow-ssh-traffic"
  network = google_compute_network.simple_server_network.id

  allow {
    protocol = "tcp"
    ports    = ["22"]
  }
  direction     = "INGRESS"
  priority      = 1000
  source_ranges = ["0.0.0.0/0"]
}

# Our simple_server VM instance
resource "google_compute_instance" "simple_server" {
  name         = "instance-simple-server"
  machine_type = "e2-micro"
  zone         = ""
  tags         = ["ssh"]

  boot_disk {
    initialize_params {
      image = "debian-cloud/debian-12"
      type = "pd-standard"
      size = "10"
    }
  }

  network_interface {
    subnetwork = google_compute_subnetwork.simple_server_subnet.id

    access_config {
      # Include this section to give the VM an external IP address
    }
  }
}
